//
// BeagleBackend.cs: Queries Beagle.  See module 'beagle'
// in GNOME CVS.
//
//
// Author:
//    Nat Friedman <nat@novell.com>
//


using System;
using System.IO;
using System.Collections;

using Gnome;
using Beagle;

[assembly:Dashboard.BackendFactory ("Dashboard.BeagleBackend")]

namespace Dashboard {

	class BeagleBackend : Backend {
		private QueryDriver queryDriver;
		private static double DECAY = 0.3; // How quickly to decay old files

		public override bool Startup ()
		{
			Console.WriteLine ("Beagle backend starting up...");

			Name = "Beagle";

			try {
				queryDriver = new QueryDriver ();
			} catch {
				Console.WriteLine ("Beagle backend: ERROR LOADING.");

				this.Initialized = false;

				return false;
			}

			this.Initialized = true;
			
			SubscribeToClues ("*", "keyword", "uri", "textblock", "content");

			return true;
		}

		static Match HitToMatch (Hit hit, Clue clue)
		{
			Match match = new Match (hit.Type, clue);

			match ["URL"]      = hit.Uri;
			match ["URI"]      = hit.Uri;
			match ["MimeType"] = hit.MimeType;
			match ["Source"]   = hit.Source;
			match ["Score"]    = hit.Score;

			foreach (String key in hit.Keys)
				match [key] = hit [key];

			// Type-specific gunk
			switch (hit.Type) {

			case "File":
				match ["Path"] = hit.Uri;
				match ["Text"] = hit.Uri.Substring (hit.Uri.LastIndexOf ('/') + 1);
				string icon = Icon.LookupByURI (hit.Uri);
				if (icon == null)
					icon = "internal:document.png";
				match ["Icon"] = icon;
				break;

			case "MailMessage":
				match ["Title"] = match ["Subject"];
				match ["Icon"] = "internal:mail.png";
				match ["Flags"] = match ["_Flags"];
				break;

			case "Contact":
				if (hit.GetData ("Photo") != null)
					match ["Photo"] = hit.GetData ("Photo");
				foreach (string key in hit.Keys)
					match [key] = hit [key];
				break;
			}

			return match;
		}

		public override BackendResult ProcessCluePacket (CluePacket cp)
		{
			if (! this.Initialized)
				return null;

			BackendResult result = new BackendResult (this, cp);

			foreach (Clue clue in cp.Clues) {
				if (! ClueTypeSubscribed (clue))
					continue;

				string clue_text = clue.Text.ToLower ();

				Query query = new Query (clue_text);
				QueryResult results = queryDriver.Query (query);
				
				// Wait for all results to come back before
				// preceeding.  (FIXME?)
				results.Wait ();


				int i = 0;
				foreach (Hit hit in results.Hits) {
					i ++;
					if (i > 10)
						break;
					Match match = HitToMatch (hit, clue);
					result.AddMatch (match);
				}
			}

			return result;
		}
	}
}
